Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(134)

Unified Diff: runtime/vm/intermediate_language.h

Issue 10857056: Replaced Value by Definition in the renaming environment. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Patch title. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/flow_graph.cc ('k') | runtime/vm/intermediate_language.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/intermediate_language.h
diff --git a/runtime/vm/intermediate_language.h b/runtime/vm/intermediate_language.h
index 71c532b6ca2b3e6c248f31784e41570b7da23105..4864a049bcc3da5efb93e0b038b4a02b90752a0e 100644
--- a/runtime/vm/intermediate_language.h
+++ b/runtime/vm/intermediate_language.h
@@ -2882,14 +2882,9 @@ class BranchInstr : public TemplateInstruction<2> {
class Environment : public ZoneAllocated {
public:
- // Construct an environment by copying from an array of values.
- explicit Environment(const GrowableArray<Value*>& values,
- intptr_t fixed_parameter_count)
- : values_(values.length()),
- locations_(NULL),
- fixed_parameter_count_(fixed_parameter_count) {
- values_.AddArray(values);
- }
+ // Construct an environment by constructing uses from an array of definitions.
+ Environment(const GrowableArray<Definition*>& definitions,
+ intptr_t fixed_parameter_count);
void set_locations(Location* locations) {
ASSERT(locations_ == NULL);
« no previous file with comments | « runtime/vm/flow_graph.cc ('k') | runtime/vm/intermediate_language.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698